@@ -17,7 +17,9 @@
 #include <windows.h>
 #else
 #include <sys/ipc.h>
+#ifndef Q_OS_HAIKU
 #include <sys/shm.h>
+#endif
 #include <unistd.h> // nice()
 #endif
 
@@ -101,6 +103,12 @@ extern "C" Q_DECL_EXPORT int kdemain(int argc, char **argv)
     // need QGuiApplication
     qunsetenv("SESSION_MANAGER");
 
+    // Some plugins may cause unwanted windows to appear
+    // (e.g. Webarchiver, see https://bugs.kde.org/show_bug.cgi?id=500173).
+    // This will not let any plugin to create auxilliary windows on the screen
+    // while generating thumbnails.
+    qputenv("QT_QPA_PLATFORM", "offscreen");
+
     // Some thumbnail plugins use QWidget classes for the rendering,
     // so use QApplication here, not just QGuiApplication
     QApplication app(argc, argv);
@@ -297,7 +305,7 @@ KIO::WorkerResult ThumbnailProtocol::get(const QUrl &url)
         // qDebug() << "IMAGE TO STREAM";
         stream << img;
     }
-#ifndef Q_OS_WIN
+#if !defined(Q_OS_WIN) && !defined(Q_OS_HAIKU)
     else {
         // qDebug() << "IMAGE TO SHMID";
         void *shmaddr = shmat(shmid.toInt(), nullptr, 0);
